@@ -1,8 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019 Intel Corporation. All rights reserved.
-# All rights reserved.
+# Copyright(c) 2019-2021 Intel Corporation. All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -47,6 +46,7 @@ import power
 
 
 class ConfigStore:
+#pylint: disable=too-many-public-methods
     """
     Class to handle config file operations
     """
@@ -112,6 +112,36 @@ class ConfigStore:
 
         return None
 
+    def get_rdt_iface(self):
+        """
+        Get RDT interface from config
+
+        Returns:
+            configured RDT interface or "msr" by default
+        """
+
+        data = self.get_config()
+
+        if 'rdt_iface' in data:
+            return data['rdt_iface']['interface']
+
+        return "msr"
+
+    def get_mba_ctrl_enabled(self):
+        """
+        Get RDT MBA CTRL Enabled from config
+
+        Returns:
+            configured RDT MBA CTRL Enabled value or "false" by default
+        """
+
+        data = self.get_config()
+
+        if 'mba_ctrl' in data:
+            return data['mba_ctrl']['enabled']
+
+        return False
+
 
     def set_path(self, path):
         """
@@ -139,6 +169,7 @@ class ConfigStore:
         """
 
         self.from_file(self.get_path())
+        self.process_config()
 
 
     @staticmethod
@@ -222,6 +253,7 @@ class ConfigStore:
 
         ConfigStore._validate_pools(data)
         ConfigStore._validate_apps(data)
+        ConfigStore._validate_rdt(data)
         power.validate_power_profiles(data, power_admission_control)
 
 
@@ -262,23 +294,6 @@ class ConfigStore:
                 for app_id in pool['apps']:
                     ConfigStore.get_app(data, app_id)
 
-            if 'cbm' in pool:
-                result = re.search('1{1,32}0{1,32}1{1,32}', bin(pool['cbm']))
-                if result or pool['cbm'] == 0:
-                    raise ValueError("Pool {}, CBM {}/{} is not contiguous."\
-                    .format(pool['id'], hex(pool['cbm']), bin(pool['cbm'])))
-                if not caps.cat_supported():
-                    raise ValueError("Pool {}, CBM {}/{}, CAT is not supported."\
-                    .format(pool['id'], hex(pool['cbm']), bin(pool['cbm'])))
-
-            if 'mba' in pool:
-                if pool['mba'] > 100 or pool['mba'] <= 0:
-                    raise ValueError("Pool {}, MBA rate {} out of range! (1-100)."\
-                    .format(pool['id'], pool['mba']))
-                if not caps.mba_supported():
-                    raise ValueError("Pool {}, MBA rate {}, MBA is not supported."\
-                    .format(pool['id'], pool['mba']))
-
             # check power profile reference
             if 'power_profile' in pool:
                 ConfigStore.get_power(data, pool['power_profile'])
@@ -340,6 +355,64 @@ class ConfigStore:
 
             pids |= set(app['pids'])
 
+    @staticmethod
+    def _validate_rdt(data):
+        """
+        Validate RDT configuration (including MBA CTRL) configuration
+
+        Parameters
+            data: configuration (dict)
+        """
+
+        # if data to be validated does not contain RDT iface and/or MBA CTRL info
+        # get missing info from current configuration
+        rdt_iface = data['rdt_iface']['interface'] if 'rdt_iface' in data\
+            else common.CONFIG_STORE.get_rdt_iface()
+        mba_ctrl_enabled = data['mba_ctrl']['enabled'] if 'mba_ctrl' in data\
+            else common.CONFIG_STORE.get_mba_ctrl_enabled()
+
+        if mba_ctrl_enabled and rdt_iface != "os":
+            raise ValueError("RDT Configuration. MBA CTRL requires RDT OS interface!")
+
+        if mba_ctrl_enabled and not caps.mba_bw_supported():
+            raise ValueError("RDT Configuration. MBA CTRL requested but not supported!")
+
+        if not 'pools' in data:
+            return
+
+        mba_pool_ids = []
+        mba_bw_pool_ids = []
+
+        for pool in data['pools']:
+
+            if 'cbm' in pool:
+                result = re.search('1{1,32}0{1,32}1{1,32}', bin(pool['cbm']))
+                if result or pool['cbm'] == 0:
+                    raise ValueError("Pool {}, CBM {}/{} is not contiguous."\
+                    .format(pool['id'], hex(pool['cbm']), bin(pool['cbm'])))
+                if not caps.cat_l3_supported():
+                    raise ValueError("Pool {}, CBM {}/{}, CAT is not supported."\
+                    .format(pool['id'], hex(pool['cbm']), bin(pool['cbm'])))
+
+            if 'mba' in pool:
+                mba_pool_ids.append(pool['id'])
+
+            if 'mba_bw' in pool:
+                mba_bw_pool_ids.append(pool['id'])
+
+        if (mba_pool_ids or mba_bw_pool_ids) and not caps.mba_supported():
+            raise ValueError("Pools {}, MBA is not supported."\
+                .format(mba_pool_ids + mba_bw_pool_ids))
+
+        if mba_bw_pool_ids and not mba_ctrl_enabled:
+            raise ValueError("Pools {}, MBA BW is not enabled/supported."\
+                .format(mba_bw_pool_ids))
+
+        if mba_pool_ids and mba_ctrl_enabled:
+            raise ValueError("Pools {}, MBA % is not enabled. Disable MBA BW and try again."\
+                .format(mba_pool_ids))
+
+        return
 
     def from_file(self, path):
         """
@@ -349,7 +422,14 @@ class ConfigStore:
             path: path to config file
         """
         self.set_path(path)
-        data = self.load(path)
+        self.namespace.config = self.load(path)
+
+
+    def process_config(self):
+        """
+        Processes/validates config
+        """
+        data = self.get_config()
 
         if not self.is_default_pool_defined(data):
             self.add_default_pool(data)
@@ -520,6 +600,42 @@ class ConfigStore:
         return result
 
 
+    def is_any_pool_defined(self):
+        """
+        Check if there is at least one pool defined
+        (other than "default" #0 one)
+
+        Returns:
+            result
+        """
+        config = self.get_config()
+
+        if 'pools' not in config:
+            return False
+
+        for pool in config['pools']:
+            if not pool['id'] == 0:
+                return True
+
+        return False
+
+
+    def recreate_default_pool(self):
+        """
+        Recreate Default pool
+        """
+        # not using get_config/set_config pair
+        # not to trigger "changed_event"
+        config = self.namespace.config
+
+        if ConfigStore.is_default_pool_defined(config):
+            ConfigStore.remove_default_pool(config)
+
+        ConfigStore.add_default_pool(config)
+
+        self.namespace.config = config
+
+
     @staticmethod
     def is_default_pool_defined(data):
         """
@@ -534,6 +650,7 @@ class ConfigStore:
 
         return False
 
+
     @staticmethod
     def add_default_pool(data):
         """
@@ -545,15 +662,18 @@ class ConfigStore:
         default_pool['id'] = 0
 
         if caps.mba_supported():
-            default_pool['mba'] = 100
+            if caps.mba_bw_enabled():
+                default_pool['mba_bw'] = 2**32 - 1
+            else:
+                default_pool['mba'] = 100
 
-        if caps.cat_supported():
+        if caps.cat_l3_supported():
             default_pool['cbm'] = common.PQOS_API.get_max_l3_cat_cbm()
 
         default_pool['name'] = "Default"
 
         # Use all unallocated cores
-        default_pool['cores'] = list(range(common.PQOS_API.get_num_cores()))
+        default_pool['cores'] = common.PQOS_API.get_cores()
         for pool in data['pools']:
             default_pool['cores'] = \
                 [core for core in default_pool['cores'] if core not in pool['cores']]
@@ -561,6 +681,17 @@ class ConfigStore:
         data['pools'].append(default_pool)
 
 
+    @staticmethod
+    def remove_default_pool(data):
+        """
+        Remove Default pool
+        """
+        for pool in data['pools'][:]:
+            if pool['id'] == 0:
+                data['pools'].remove(pool)
+                break
+
+
     def get_new_pool_id(self, new_pool_data):
         """
         Get ID for new Pool
@@ -570,10 +701,10 @@ class ConfigStore:
         """
         # get max cos id for combination of allocation technologies
         alloc_type = []
-        if 'mba' in new_pool_data:
+        if 'mba' in new_pool_data or 'mba_bw' in new_pool_data:
             alloc_type.append(common.MBA_CAP)
         if 'cbm' in new_pool_data:
-            alloc_type.append(common.CAT_CAP)
+            alloc_type.append(common.CAT_L3_CAP)
         max_cos_id = common.PQOS_API.get_max_cos_id(alloc_type)
 
         data = self.get_config()
