@@ -1,8 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019-2020 Intel Corporation. All rights reserved.
-# All rights reserved.
+# Copyright(c) 2019-2021 Intel Corporation. All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -46,7 +45,6 @@ import power
 import sstbf
 
 from rest.rest_exceptions import BadRequest, InternalError
-from rest.rest_auth import auth
 
 from config import ConfigStore
 from stats import StatsStore
@@ -59,7 +57,6 @@ class Stats(Resource):
 
 
     @staticmethod
-    @auth.login_required
     def get():
         """
         Handles HTTP GET /stats request.
@@ -83,7 +80,6 @@ class Caps(Resource):
 
 
     @staticmethod
-    @auth.login_required
     def get():
         """
         Handles HTTP GET /caps request.
@@ -103,7 +99,6 @@ class Sstbf(Resource):
 
 
     @staticmethod
-    @auth.login_required
     def get():
         """
         Handles HTTP GET /caps/sstbf request.
@@ -121,7 +116,6 @@ class Sstbf(Resource):
 
 
     @staticmethod
-    @auth.login_required
     def put():
         """
         Handles HTTP PUT /caps/sstbf request.
@@ -136,7 +130,7 @@ class Sstbf(Resource):
         try:
             schema, resolver = ConfigStore.load_json_schema('modify_sstbf.json')
             jsonschema.validate(json_data, schema, resolver=resolver)
-        except jsonschema.ValidationError as error:
+        except (jsonschema.ValidationError, OverflowError) as error:
             raise BadRequest("Request validation failed - %s" % (str(error)))
 
         if not sstbf.configure_sstbf(json_data['configured']) == 0:
@@ -156,7 +150,6 @@ class Reset(Resource):
 
 
     @staticmethod
-    @auth.login_required
     def post():
         """
         Handles HTTP POST /reset request.
