@@ -1,8 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019-2020 Intel Corporation. All rights reserved.
-# All rights reserved.
+# Copyright(c) 2019-2021 Intel Corporation. All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -75,10 +74,6 @@ CONFIG = {
             "pids": [4]
         }
     ],
-    "auth": {
-        "password": "password",
-        "username": "user"
-    },
     "pools": [
         {
             "cores": [20, 21, 22],
@@ -143,10 +138,6 @@ CONFIG = {
 
 
 CONFIG_EMPTY = {
-    "auth": {
-        "password": "password",
-        "username": "user"
-    }
 }
 
 
