@@ -43,10 +43,8 @@
 #include "resctrl.h"
 #include "resctrl_alloc.h"
 #include "perf_monitoring.h"
-
-#define PROC_CPUINFO     "/proc/cpuinfo"
-#define PROC_FILESYSTEMS "/proc/filesystems"
-#define PROC_MOUNTS      "/proc/mounts"
+#include "cpuinfo.h"
+#include "os_common.h"
 
 static int mba_ctrl = -1; /**< mba ctrl support */
 
@@ -117,22 +115,12 @@ get_shareable_bits(const char *dir, uint64_t *shareable_bits)
 int
 os_cap_init(const enum pqos_interface inter)
 {
-        int ret;
-        int res_flag = 0;
+        int ret = PQOS_RETVAL_OK;
 
         /**
          * resctrl detection
          */
-        ret = pqos_file_contains(PROC_FILESYSTEMS, "resctrl", &res_flag);
-        if (ret != PQOS_RETVAL_OK) {
-                LOG_ERROR("Fatal error encountered in resctrl detection!\n");
-                return ret;
-        }
-        LOG_INFO("%s\n", res_flag ? "resctrl detected"
-                                  : "resctrl not detected. "
-                                    "Kernel version 4.10 or higher required");
-
-        if (res_flag == 0) {
+        if (resctrl_is_supported() != PQOS_RETVAL_OK) {
                 LOG_ERROR("OS interface selected but not supported\n");
                 return PQOS_RETVAL_INTER;
         }
@@ -583,6 +571,7 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                     int *supported,
                     int *enabled)
 {
+        const struct cpuinfo_config *vconfig;
         int ret;
 
         ret = pqos_mba_ctrl_enabled(cap, supported, enabled);
@@ -606,7 +595,9 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                         return ret;
         }
 
-        /* check for values above 100 */
+        cpuinfo_get_config(&vconfig);
+
+        /* check for values above mba_max */
         if (*enabled == -1) {
                 unsigned grp;
                 unsigned count = 0;
@@ -638,7 +629,8 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
 
                                 ret = resctrl_schemata_mba_get(
                                     schmt, mba_ids[i], &mba);
-                                if (ret == PQOS_RETVAL_OK && mba.mb_max > 100) {
+                                if (ret == PQOS_RETVAL_OK &&
+                                    mba.mb_max > vconfig->mba_max) {
                                         *enabled = 1;
                                         break;
                                 }
@@ -649,7 +641,7 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                 free(mba_ids);
         }
 
-        /* get free COS and try to write value above 100 */
+        /* get free COS and try to write value over the mba_max */
         if (*enabled == -1) {
                 unsigned grp;
                 unsigned count = 0;
@@ -675,7 +667,7 @@ os_cap_get_mba_ctrl(const struct pqos_cap *cap,
                 if (ret == PQOS_RETVAL_OK) {
                         fd = resctrl_alloc_fopen(grp, "schemata", "w");
                         if (fd != NULL) {
-                                fprintf(fd, "MB:0=2000\n");
+                                fprintf(fd, "MB:0=%u\n", vconfig->mba_max * 2);
                                 if (fclose(fd) == 0)
                                         *enabled = 1;
                                 else
