@@ -56,7 +56,7 @@ extern "C" {
  * =======================================
  */
 
-#define PQOS_VERSION      40200 /**< version 4.2.0 */
+#define PQOS_VERSION      40300 /**< version 4.3.0 */
 #define PQOS_MAX_COS      16    /** 16 x COS */
 #define PQOS_MAX_L3CA_COS PQOS_MAX_COS
 #define PQOS_MAX_L2CA_COS PQOS_MAX_COS
@@ -75,6 +75,7 @@ extern "C" {
 #define PQOS_RETVAL_PERF_CTR  6 /**< performance counter error */
 #define PQOS_RETVAL_BUSY      7 /**< resource busy error */
 #define PQOS_RETVAL_INTER     8 /**< Interface not supported */
+#define PQOS_RETVAL_OVERFLOW  9 /**< Data overflow */
 
 /*
  * =======================================
@@ -82,9 +83,10 @@ extern "C" {
  * =======================================
  */
 enum pqos_interface {
-        PQOS_INTER_MSR = 0,           /**< MSR */
-        PQOS_INTER_OS = 1,            /**< OS */
-        PQOS_INTER_OS_RESCTRL_MON = 2 /**< OS with resctrl monitoring */
+        PQOS_INTER_MSR = 0,            /**< MSR */
+        PQOS_INTER_OS = 1,             /**< OS */
+        PQOS_INTER_OS_RESCTRL_MON = 2, /**< OS with resctrl monitoring */
+        PQOS_INTER_AUTO = 3            /**< Auto detection */
 };
 
 /*
@@ -392,6 +394,16 @@ struct pqos_cpuinfo {
  */
 int pqos_cap_get(const struct pqos_cap **cap, const struct pqos_cpuinfo **cpu);
 
+/**
+ * @brief Retrieves PQoS interface
+ *
+ * @param [out] interface PQoS interface
+ *
+ * @return Operation status
+ * @retval PQOS_RETVAL_OK on success, error code otherwise
+ */
+int pqos_inter_get(enum pqos_interface *interface);
+
 /*
  * =======================================
  * Monitoring
@@ -578,6 +590,7 @@ int pqos_mon_stop(struct pqos_mon_data *group);
  * @param [in] num_groups number of monitoring groups in the table
  *
  * @return Operations status
+ * @retval PQOS_RETVAL_OVERFLOW MBM counter overflow
  * @retval PQOS_RETVAL_OK on success
  */
 int pqos_mon_poll(struct pqos_mon_data **groups, const unsigned num_groups);
