@@ -1,8 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019-2020 Intel Corporation. All rights reserved.
-# All rights reserved.
+# Copyright(c) 2019-2021 Intel Corporation. All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -33,7 +32,6 @@
 
 import subprocess
 import re
-import time
 import test
 import pytest
 from testlib.resctrl import Resctrl
@@ -70,26 +68,27 @@ class TestRdtsetMba(test.Test):
     @pytest.mark.rdt_supported("mba")
     def test_rdtset_mba_set_command(self, iface):
         command = self.cmd_rdtset(iface, "-t mba=50;cpu=5-6 -c 5-6 memtester 10M")
-        rdtset = subprocess.Popen(command.split(), stdin=subprocess.PIPE, stdout=subprocess.PIPE)
+        with subprocess.Popen(command.split(), stdin=subprocess.PIPE,
+                              stdout=subprocess.PIPE) as rdtset:
 
-        time.sleep(0.1)
+            self.stdout_wait(rdtset, b"memtester version")
 
-        (stdout, _, exitstatus) = self.run_pqos(iface, "-s")
-        assert exitstatus == 0
+            (stdout, _, exitstatus) = self.run_pqos(iface, "-s")
+            assert exitstatus == 0
 
-        if iface == "MSR":
-            last_cos = Env().get('mba', 'cos') - 1
-        else:
-            last_cos = Resctrl.get_ctrl_group_count() - 1
+            if iface == "MSR":
+                last_cos = Env().get('mba', 'cos') - 1
+            else:
+                last_cos = Resctrl.get_ctrl_group_count() - 1
 
-        assert re.search("Core 5, L2ID [0-9]+, L3ID [0-9]+ => COS%d" % last_cos, stdout) \
-               is not None
-        assert re.search("Core 6, L2ID [0-9]+, L3ID [0-9]+ => COS%d" % last_cos, stdout) \
-               is not None
-        assert "MBA COS{} => 50% available".format(last_cos) in stdout
+            assert re.search("Core 5, L2ID [0-9]+, L3ID [0-9]+ => COS%d" % last_cos, stdout) \
+                   is not None
+            assert re.search("Core 6, L2ID [0-9]+, L3ID [0-9]+ => COS%d" % last_cos, stdout) \
+                   is not None
+            assert "MBA COS{} => 50% available".format(last_cos) in stdout
 
-        self.run("killall memtester")
-        rdtset.communicate()
+            self.run("killall memtester")
+            rdtset.communicate()
 
 
 
