@@ -364,6 +364,12 @@ test_hw_cap_l3ca_discover_unsupported(void **state)
         _lcpuid_add(0x07, 0x0, 0x0, 0x8000, 0x0, 0x0);
         _lcpuid_add(0x10, 0x0, 0x0, 0x0, 0x0, 0x0);
 
+        /* brand string */
+        _lcpuid_add(0x80000000, 0x0, 0x80000008, 0x0, 0x0, 0x0);
+        _lcpuid_add(0x80000002, 0x0, 0x0, 0x0, 0x0, 0x0);
+        _lcpuid_add(0x80000003, 0x0, 0x0, 0x0, 0x0, 0x0);
+        _lcpuid_add(0x80000004, 0x0, 0x0, 0x0, 0x0, 0x0);
+
         ret = hw_cap_l3ca_discover(&cap_l3ca, data->cpu);
         assert_int_equal(ret, PQOS_RETVAL_RESOURCE);
 }
@@ -640,4 +646,4 @@ main(void)
             cmocka_run_group_tests(tests, test_init_unsupported, test_fini);
 
         return result;
-}
\ No newline at end of file
+}
