@@ -82,4 +82,11 @@ void
 __wrap__pqos_cap_mba_change(const enum pqos_mba_config cfg)
 {
         check_expected(cfg);
-}
\ No newline at end of file
+}
+
+void
+__wrap__pqos_inter_get(enum pqos_interface *interface)
+{
+        if (interface != NULL)
+                *interface = mock_type(enum pqos_interface);
+}
